import json


def _exception(func):
    def inner(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except Exception as ex:
            return _ret(ex.code, ex.msg)

    return inner


def _ret(ret, msg, data={}):
    return {
        "isBase64Encoded": not isinstance({}, dict),
        "statusCode": 200,
        "headers": {
            "Content-Type": 'application/json'
        },
        "body": json.dumps({
            'code': ret,
            'msg': msg,
            'data': data
        })
    }




import time
import math

# 定义一些时间段的常量（秒）
TimeSec_Hour = 3600
TimeSec_Day = 86400
TimeSec_Week = 604800
TimeSec_Month = 2592000
TimeSec_Year = 31536000


def timestamp_sec(timestamp):
    if timestamp_is_ms(timestamp):
        return round(timestamp / 1000)
    else:
        return timestamp


def timestamp_ms(timestamp):
    if timestamp_is_ms(timestamp):
        return timestamp
    else:
        return timestamp * 1000


def timestamp_is_ms(timestamp):
    return timestamp > 1000000000000


def format_duration(duration, ms=False):
    if ms:
        duration = round(duration / 60)
    sec = duration % 60
    minute = math.floor((duration % 3600) / 60)
    hour = math.floor((duration % 86400) / 3600)
    day = math.floor(duration / 86400)
    if day > 0:
        ret = ''.join([str(day), "天"])
        if hour > 0:
            ret = ''.join([ret, str(hour), "小时"])
    elif hour > 0:
        ret = ''.join([str(hour), "小时"])
        if minute > 0:
            ret = ''.join([ret, str(minute), "分钟"])
    elif minute > 0:
        ret = ''.join([str(minute), "分钟"])
        if sec > 0:
            ret = ''.join([ret, str(sec), "秒"])
    else:
        ret = ''.join([str(sec), '秒'])
    return ret


def datetime_format(timestamp, ms=False):
    if ms:
        timestamp = int(timestamp / 1000)
    time_array = time.localtime(timestamp)
    return time.strftime("%Y-%m-%d %H:%M:%S", time_array)


def dateformat(timestamp, ms=False):
    if ms:
        timestamp = int(timestamp / 1000)
    time_array = time.localtime(timestamp)
    return time.strftime("%Y-%m-%d", time_array)


def timeformat(format_string, timestamp, ms=False):
    if ms:
        timestamp = int(timestamp / 1000)
    time_array = time.localtime(timestamp)
    return time.strftime(format_string, time_array)


def datetime_to_stamp(time_string, ms=False):
    time_array = time.strptime(time_string, "%Y-%m-%d %H:%M:%S")
    ret = int(time.mktime(time_array))
    if ms:
        ret = ret * 1000
    return ret


def date_to_stamp(date_string, ms=False):
    try:
        time_array = time.strptime(date_string, "%Y-%m-%d")
        ret = int(time.mktime(time_array))
    except ValueError:
        ret = 0
    if ms:
        ret = ret * 1000
    return ret


def get_timestamp(ms=False):
    if ms:
        return int(round(time.time() * 1000))
    else:
        return int(time.time())


def get_daystart(timestamp=0, ms=False):
    if timestamp == 0:
        timestamp = int(time.time())
    elif ms:
        timestamp = int(timestamp / 1000)
    midnight = date_to_stamp(dateformat(timestamp))
    if ms:
        midnight = midnight * 1000
    return midnight


def get_dayend(timestamp=0, ms=False):
    if ms:
        timestamp = int(timestamp / 1000)
    ret = get_daystart(timestamp) + 86399
    if ms:
        ret = ret * 1000 + 999
    return ret


def datetime_format_utc(timestamp):
    return time.strftime("%Y-%m-%dT%H:%M:%SZ", timestamp)



import requests
import json


header = {'Content-Type': 'application/x-www-form-urlencoded'}


def ret(response):
    if isinstance(response, dict):
        return json.dumps(response, sort_keys=True, indent=4)
    else:
        return response


def send_get(url, params=None, headers=header):
    response = requests.get(url=url, params=params, headers=headers)
    return ret(response)


def send_post(url, data={}, headers=header):
    response = requests.post(url=url, data=data, headers=headers)
    return ret(response)


def send_put(url, data={}, headers=header):
    response = requests.put(url=url, data=data, headers=headers)
    return ret(response)


def send_delete(url, data={}, headers=header):
    response = requests.delete(url=url, data=data, headers=headers)
    return ret(response)



#!/usr/bin/env python
# -*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: bright
# Mail: brightmail@vip.qq.com
# Created Time:  2018-05-24 16:25:34
#############################################


from setuptools import setup, find_packages

setup(
    name="bright",
    version="0.0.11",
    keywords=["tool", "bright"],
    description="bright tool",
    long_description="bright tool etc",
    license="MIT Licence",

    url="https://github.com/brightlike/Christmastree/",
    author="bright",
    author_email="brightmail@vip.qq.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=['chardet', 'requests']
)



# coding: utf-8
import time
import random
import hashlib
import requests


def run(content):
    url = 'http://fanyi.youdao.com/translate_o?smartresult=dict&smartresult=rule&sessionFrom='

    s = "AUTO",
    l = "AUTO"
    u = 'fanyideskweb'
    # c = 'rY0D^0\'nM0}g5Mm1z%1G4'
    c = 'Tbh5E8=q6U3EXe+&L[4c@'
    d = content
    f = str(int(time.time() * 1000) + random.randint(1, 10))
    sign = hashlib.md5((u + d + f + c).encode('utf-8')).hexdigest()

    headers = {
        'Accept': 'application/json, text/javascript, */*; q=0.01',
        'Accept-Encoding': 'gzip, deflate',
        'Accept-Language': 'zh-CN,zh;q=0.8,en;q=0.6',
        'Connection': 'keep-alive',
        'Content-Length': '205',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'Cookie': 'UM_distinctid=178cf7f009a7b-007573c2d50af8-336a7c0e-1aeaa0-178cf7f009b461; NTES_YD_SESS=7gCAKxIvH5u3TZI5qQhbsT28bm1VacJ7kWwul8xhlsIfpvFRpWZ9_iFz8xswzqT8wTLti50eADPE6yBkUUOMYcT_MZ2NMq3pc0OcANyZTlFnSLxcDiTBKaoyFXGJ03FlXJA8Jmg_Gf4EHfhvFOxFmAek4ukYsvNKdqVLN5E83SXuNeRBz0yixGpSTPCPJfgIrJyMRGhxzXpQ01MseS7md3HAuJSIv5d8qCZB1ZVk4LgJN; S_INFO=1618388939|0|3&80##|13530552114; P_INFO=13530552114|1618388939|1|youdao_zhiyun2018|00&99|null&null&null#gud&440300#10#0|&0||13530552114; OUTFOX_SEARCH_USER_ID=-1426560297@10.169.0.83; JSESSIONID=aaaJeb0d4WdO1gO3DLpJx; OUTFOX_SEARCH_USER_ID_NCOO=585287449.5053693; ___rl__test__cookies=1618390422014',
        'Host': 'fanyi.youdao.com',
        'Origin': 'http://fanyi.youdao.com',
        'Referer': 'http://fanyi.youdao.com/',
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.90 Safari/537.36',
        'X-Requested-With': 'XMLHttpRequest',
    }

    data = {}
    data['i'] = content
    data['from'] = s
    data['to'] = l
    data['smartresult'] = 'dict'
    data['client'] = 'fanyideskweb'
    data['salt'] = f
    data['sign'] = sign
    data['doctype'] = 'json'
    data['version'] = '2.1'
    data['keyfrom'] = 'fanyi.web'
    data['action'] = 'FY_BY_CLlCKBUTTON'
    data['typoResult'] = 'true'
    data['bv'] = 'ffc36c076d715bacb38ac2edc5def978'

    res = requests.post(url, data, headers=headers)
    print(res.json())
    say = res.json()['translateResult'][0][0]['tgt']
    return say



def printtree(tree_h=20, leaves=1):
    for i in range(tree_h):
        print((' ' * (tree_h - i)) + ('*' * leaves))
        leaves += 2
    for j in range(tree_h):
        print ((' ' * tree_h) + '*')
